@@ -91,13 +91,17 @@ class Config:
     # Add the truecaser config info to the config file
     @staticmethod
     def add_truecaser(
-        src_truecaser: bool, tgt_truecaser: bool, project_dir: pathlib.Path
+        src_truecaser: bool,
+        tgt_truecaser: bool,
+        pretrained: str,
+        project_dir: pathlib.Path
     ):
         with open(project_dir.joinpath("config.yml"), "r") as file:
             data = yaml.load(file, Loader=yaml.FullLoader)
             data["truecaser"] = {
                 "src": "enabled" if src_truecaser else "disabled",
                 "tgt": "enabled" if tgt_truecaser else "disabled",
+                "pretrained": pretrained
             }
 
             total_data = {
@@ -161,6 +165,7 @@ class Config:
         joint: bool,
         num_iterations: int,
         threshold: int,
+        pretrained: str,
         project_dir: pathlib.Path,
     ):
 
@@ -168,6 +173,7 @@ class Config:
             "joint": joint,
             "threshold": threshold,
             "num_iterations": num_iterations,
+            "pretrained": pretrained,
         }
 
         with open(project_dir.joinpath("config.yml"), "r") as file:
