@@ -1,6 +1,8 @@
 import subprocess
+import shutil
 import os
 import click
+import pathlib
 from pathos.multiprocessing import Pool
 from pangeamt_nlp.tokenizer.tokenizer_factory import TokenizerFactory
 from pangeamt_tea.project.workflow.stage.base_stage import BaseStage
@@ -268,27 +270,42 @@ class PrepareStage(BaseStage):
 
     # Create truecase model
     def create_truecase_model(self, prev_dir: str, max_workers: int):
+        config = self.workflow.project.config
         dir = os.path.join(self.stage_dir, "truecase_model")
-        os.mkdir(dir)
         src_model_path = os.path.join(dir, "src_model.txt")
         tgt_model_path = os.path.join(dir, "tgt_model.txt")
 
-        def make_path(file: str):
-            return os.path.join(prev_dir, file)
+        if config.truecaser["pretrained"] is not None:
+            try:
+                from pangeamt_tea.project.project import Project
+                path = config.truecaser["pretrained"]
+                # Checks if the folder is a project or the model folder
+                project = Project.load(pathlib.Path(path))
+                model_path = os.path.join(
+                    path, "workflow", "02_prepared", "truecase_model"
+                )
+                os.symlink(model_path, dir)
+            except Exception:
+                os.symlink(config.truecaser["pretrained"], dir)
+        else:
+            os.mkdir(dir)
 
-        if self.workflow.project.config.truecaser["src"] == "enabled":
-            Truecaser().train_from_file(
-                make_path("train_src.txt"),
-                save_to=src_model_path,
-                processes=max_workers
-            )
+            def make_path(file: str):
+                return os.path.join(prev_dir, file)
 
-        if self.workflow.project.config.truecaser["tgt"] == "enabled":
-            Truecaser().train_from_file(
-                make_path("train_tgt.txt"),
-                save_to=tgt_model_path,
-                processes=max_workers
-            )
+            if self.workflow.project.config.truecaser["src"] == "enabled":
+                Truecaser().train_from_file(
+                    make_path("train_src.txt"),
+                    save_to=src_model_path,
+                    processes=max_workers
+                )
+
+            if self.workflow.project.config.truecaser["tgt"] == "enabled":
+                Truecaser().train_from_file(
+                    make_path("train_tgt.txt"),
+                    save_to=tgt_model_path,
+                    processes=max_workers
+                )
 
         return (src_model_path, tgt_model_path)
 
@@ -377,31 +394,45 @@ class PrepareStage(BaseStage):
 
     # Create BPE model
     def create_bpe_model(self, prev_dir, joint):
+        config = self.workflow.project.config
         dir = os.path.join(self.stage_dir, "bpe_model")
-        os.mkdir(dir)
-
-        iterations = self.workflow.project.config.bpe["num_iterations"]
-
         src_input_path = os.path.join(prev_dir, "train_src.txt")
         tgt_input_path = os.path.join(prev_dir, "train_tgt.txt")
 
-        if joint:
-            codes_path = os.path.join(dir, "codes32k.txt")
-            src_vocab_path = os.path.join(dir, "src_vocab.txt")
-            tgt_vocab_path = os.path.join(dir, "tgt_vocab.txt")
-            BPE.learn_joint(
-                src_input_path,
-                tgt_input_path,
-                codes_path,
-                src_vocab_path,
-                tgt_vocab_path,
-                iterations,
-            )
+        if config.bpe["pretrained"]:
+            try:
+                from pangeamt_tea.project.project import Project
+                path = config.bpe["pretrained"]
+                # Checks if the folder is a project or the model folder
+                project = Project.load(pathlib.Path(path))
+                model_path = os.path.join(
+                    path, "workflow", "02_prepared", "bpe_model"
+                )
+                os.symlink(model_path, dir)
+            except Exception:
+                os.symlink(config.bpe["pretrained"], dir)
         else:
-            src_model_path = os.path.join(dir, "src_codes.txt")
-            tgt_model_path = os.path.join(dir, "tgt_codes.txt")
-            BPE.learn(src_input_path, src_model_path, iterations)
-            BPE.learn(tgt_input_path, tgt_model_path, iterations)
+            os.mkdir(dir)
+
+            iterations = self.workflow.project.config.bpe["num_iterations"]
+
+            if joint:
+                codes_path = os.path.join(dir, "codes32k.txt")
+                src_vocab_path = os.path.join(dir, "src_vocab.txt")
+                tgt_vocab_path = os.path.join(dir, "tgt_vocab.txt")
+                BPE.learn_joint(
+                    src_input_path,
+                    tgt_input_path,
+                    codes_path,
+                    src_vocab_path,
+                    tgt_vocab_path,
+                    iterations,
+                )
+            else:
+                src_model_path = os.path.join(dir, "src_codes.txt")
+                tgt_model_path = os.path.join(dir, "tgt_codes.txt")
+                BPE.learn(src_input_path, src_model_path, iterations)
+                BPE.learn(tgt_input_path, tgt_model_path, iterations)
 
         return dir
 
